%-------- subroutine ims.m------------%
function [o18e,o18l,o18s,o18c,o18cc]=ims(pr,ta,rh,dfs,dfb,efc,blc,c10,c11,pl,feo,fwxm,c1,c2,c3,c4,c5,c6,c7,c8)
                                                                                                                                           
% Parameterized variable calculations
                                                                                                                                           
o18sw = c1 + c2*pr;
lt= c3 + c4.*ta;
tc=-c6*c5+273.15+ta;
alv=exp(1137./tc.^2 -0.4156./tc -0.00207);
o18wva=1000*(1./alv-1)+o18sw;  % Majoube, 1971; referenced in
                               % Gonfiantini et al., 2001:
                               % equilibrium fraction between water
                               % liquid and vapor
%o18wva = o18sw - 8;
                                                                                                                                           
% Constants
                                                                                                                                           
rsmow=0.0020052; % 18/16 ratio for intl working std
cw=55500; % concentration of water (mol/m^3)
dw=0.00000000266; % diffusivity of H218O in water (m^2/s)
                                                                                                                                           
% calculated parameters
                                                                                                                                           
% environmental conditions
svpa=(6.13753.*exp(ta.*((18.564-(ta./254.4)))./(ta+255.57))); % saturated vapour pressure of the air (mbar)
avpa=(rh./100).*svpa; % actual vapour pressure of the air (mbar)
rsw=((o18sw./1000)+1)*rsmow; % 18O/16O of source water
rwv=((o18wva./1000)+1)*rsmow; % 18O/16O of water vapour
do18wvs=((rwv./rsw)-1)*1000;  % delta 18O of water vapour (per mil, wrt source water)
                                                                                                                                           
% leaf evaporative conditions
vpl=(6.13753.*exp(lt.*((18.564-(lt./254.4)))./(lt+255.57))); % leaf internal vapour pressure (mbar)
vpd=vpl-avpa; % leaf - air saturation vapor pressure deficit (mbar)
sc=c10./vpd + c11; % Lohammar function for sc=f(vpd); vpd units in mb; sc units in mmol/m^2/sec
tr=sc.*vpd./1013; % tr = sc*vpd/Patm (mb);
% Note for tr calculation, atmospheric pressure is assumed constant at sea level value;
% this should be adjusted for sites at appreciable elevation, or input as monthly timeseries
p=((tr./1000)*pl)./(cw*dw); % Peclet number
% fractionation factors
tdf=(((1./sc).*dfs)+((1/blc)*dfb))./((1/blc)+(1./sc)); % total diffusive fractionation (per mil)
evpf=((exp((1137./((lt+273.16).^2))-(0.4156./(lt+273.16))-0.0020667))-1)*1000; % equilibrium vapour pressure fractionation (per mil)
                                                                                                                                           
% outputs
do18e=(((1+(evpf./1000)).*(1+(tdf./1000)+(((do18wvs./1000)-(tdf./1000)).*(avpa./vpl))))-1).*1000; % Craig-Gordon evaporation-site water (D\18Oe) (per mil wrt source water )
do18l=(do18e.*(1-(exp(-p))))./p; % Bulk leaf water (D18OL) (per mil wrt source water)
do18s=do18l+efc; % Sucrose D18O (per mil wrt source water)
do18c=do18l.*(1-(fwxm*feo))+efc; % Cellulose D18O (per mil wrt source water)
                                                                                                                                           
%     [do18e; do18l; do18s; do18c];
                                                                                                                                           
%convert back into ratios wrt SMOW:
M=1000;
o18e=(((do18e./M+1).*rsw)./rsmow-1).*M;
o18l=(((do18l./M+1).*rsw)./rsmow-1).*M;
o18s=(((do18s./M+1).*rsw)./rsmow-1).*M;
o18c=(((do18c./M+1).*rsw)./rsmow-1).*M;
                                                                                                                                           
% correct to observed o18 given observed mean (c7)
% and fraction (c8) water from meteoric sources
j=find(~isnan(o18c));
o18cc=o18c;
o18cc(j)=c8.*(o18c(j)-(mean(o18c(j))-c7))+(1-c8).*c7;
                                                                                                                                           
return
                                                                                                                                           
%------------------
                                                                                                                                           
% References cited:
%
% M.M. Barbour, J.S. Roden, G.D. Farquhar, J.R. Ehleringer, 2004,
% Expressing leaf water and cellulose oxygen isotope ratios as
% enrichment above source water reveals evidence of a Peclet effect,
% Oecologia 138:426-435, doi 10.1007/s00442-003-1449-3 excel model
% from ftp://ecophys.biology.utah.edu/tree_ring/
%
% Lachniet, M.S. and W.P. Patterson, 2006: Use of correlation and
% stepwise regression to evaluate physical controls on the stable
% isotope values of Panamanian surface waters, J. Hydrology, 324(1-4),
% 115-140.
%
% Lawrence, J.R. and S.D. Gedzelman, 2003: Tropical ice cores: Do they
% reflect changes in storm activity?, Geophys. Res. Lett., 30(2), 1072,
% DOI:10.1029/2002GL015906.
%
% Lawrence, J.R. and S.D. Gedzelman, D. Dexheimer, H.-K. Cho, G.D. Carrie,
% R. Gasparini, C.R. Anderson, K.P. Bowman and M.I. Biggerstaff, 2004:
% Stable isotopic composition of water vapor in the tropics, J. Geophys.
% Res., 109, D06115, DOI:10.1029/2003JD004046.
%
% Linacre, E.T., 1964: A note on a feature of leaf and air
% temperatures, Agr. Meteorol. 1:66-72.
%
% Wallace, J.M. and P.V. Hobbs, 1977: Atmospheric Science: An Intro-
% ductory Survey, New York: Academic Press, 467 pp.
                                                                                                                                           
                                                                                                                                           

